@@ -21,6 +21,8 @@ from pycha.chart import DEFAULT_OPTIONS
 from pycha.bar import HorizontalBarChart, VerticalBarChart
 from pycha.line import LineChart
 from pycha.pie import PieChart
+from pycha.radial import RadialChart
+from pycha.polygonal import PolygonalChart
 from pycha.scatter import ScatterplotChart
 from pycha.stackedbar import StackedVerticalBarChart, StackedHorizontalBarChart
 
@@ -34,6 +36,8 @@ class App(object):
         HorizontalBarChart,
         LineChart,
         PieChart,
+        RadialChart,
+        PolygonalChart,
         ScatterplotChart,
         StackedVerticalBarChart,
         StackedHorizontalBarChart,
@@ -43,6 +47,8 @@ class App(object):
      HORIZONTAL_BAR_TYPE,
      LINE_TYPE,
      PIE_TYPE,
+     RADIAL_TYPE,
+     POLYGONAL_TYPE,
      SCATTER_TYPE,
      STACKED_VERTICAL_BAR_TYPE,
      STACKED_HORIZONTAL_BAR_TYPE) = range(len(CHART_TYPES))
@@ -55,7 +61,6 @@ class App(object):
             labelColor=str,
             labelFont=str,
             labelFontSize=int,
-            labelWidth=float,
             tickFont=str,
             tickFontSize=int,
             x=dict(
