@@ -1,4 +1,4 @@
-# Copyright (c) 2007-2008 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
+# Copyright (c) 2007-2010 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
 #
 # This file is part of PyCha.
 #
@@ -71,7 +71,6 @@ class PieTests(unittest.TestCase):
         self.assertEqual(ch.slices, [])
         self.assertEqual(ch.centerx, 0)
         self.assertEqual(ch.centery, 0)
-        self.assertEqual(ch.radius, 0)
 
     def test_updateChart(self):
         surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, 500, 500)
@@ -84,11 +83,9 @@ class PieTests(unittest.TestCase):
                'pieRadius': 0.5}
         ch = pycha.pie.PieChart(surface, opt)
         ch.addDataset(dataset)
-        ch._updateXY()
-        ch._updateChart()
+        ch.render()
         self.assertEqual(ch.centerx, 250)
         self.assertEqual(ch.centery, 250)
-        self.assertEqual(ch.radius, 250)
 
         slices = (
             pycha.pie.Slice('dataset1', 0.1, 0, 10, 0),
@@ -136,6 +133,34 @@ class PieTests(unittest.TestCase):
                                      (1, 'Second dataset (20.0%)'),
                                      (2, 'Third dataset (70.0%)')])
 
+    def test_issue5(self):
+        """See http://bitbucket.org/lgs/pycha/issue/5/"""
+        surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, 500, 500)
+        dataset = (
+            ('dataset1', ([0, 30],)),
+            ('dataset2', ([0, 0],)), # Empty set!!
+            ('dataset3', ([0, 70],)),
+            )
+        ch = pycha.pie.PieChart(surface, {})
+        ch.addDataset(dataset)
+        ch._updateXY()
+        ch._updateChart()
+
+        # there is no slice for the empty set
+        slices = (
+            pycha.pie.Slice('dataset1', 0.3, 0, 30, 0),
+            pycha.pie.Slice('dataset3', 0.7, 2, 70, 0.3),
+            )
+
+        for i, slice in enumerate(slices):
+            s1, s2 = ch.slices[i], slice
+            self.assertEqual(s1.name, s2.name)
+            self.assertAlmostEqual(s1.fraction, s2.fraction, 4)
+            self.assertAlmostEqual(s1.startAngle, s2.startAngle, 4)
+            self.assertAlmostEqual(s1.endAngle, s2.endAngle, 4)
+            self.assertEqual(s1.xval, s2.xval)
+            self.assertEqual(s1.yval, s2.yval)
+
 
 def test_suite():
     return unittest.TestSuite((
